@@ -17,6 +17,8 @@ from os import path
 import re
 import mmap
 from collections import OrderedDict
+import tempfile
+import subprocess
 
 import parse
 from ast import *
@@ -62,7 +64,7 @@ def remove_headers_from_dir(header_dir):
     logger.info('Clearing header files out of ' + header_dir)
     for item in os.listdir(header_dir):
         p = path.join(header_dir, item)
-        if path.splitext(p)[1] == '.h':
+        if item != 'common.h' and path.splitext(p)[1] == '.h':
             os.remove(p)
 
 def struct_regex_string(struct_name):
@@ -110,6 +112,24 @@ def c_function(return_type, name, arg_list, body):
     result += '}\n'
     return result
 
+def write_tmp_file(text):
+    f = tempfile.NamedTemporaryFile(mode='w', delete=True)
+    f.write(text)
+    f.flush()
+    return f
+
+def diff_between(old, new):
+    old_f = write_tmp_file(old)
+    new_f = write_tmp_file(new)
+    result = subprocess.run(['diff', old_f.name, new_f.name], capture_output=True, text=True)
+    code = ''
+    for line in result.stdout.splitlines():
+        if line.startswith('<'):
+            code += '// -' + line[1:] + '\n'
+        elif line.startswith('>'):
+            code += '// +' + line[1:] + '\n'
+    return code
+
 class ResolveContext:
     def __init__(self, project, struct, version):
         self.project = project
@@ -352,10 +372,7 @@ class Struct:
         body += 'static int version_id = -1;\n'
         body += '\n'
         body += 'if (version_id == -1) {\n'
-        body += INDENT + 'if (gtk_get_major_version() != 3) {\n'
-        body += INDENT * 2 + 'g_error("' + PROJECT_NAME + ' only supports GTK3");\n'
-        body += INDENT * 2 + 'g_abort();\n'
-        body += INDENT + '}\n'
+        body += INDENT + 'gtk_priv_assert_gtk_version_valid();'
         body += '\n'
         body += INDENT + 'int combo = gtk_get_minor_version() * 1000 + gtk_get_micro_version();\n'
         body += '\n'
@@ -366,11 +383,7 @@ class Struct:
         body += INDENT * 3 + 'break;\n'
         body += '\n'
         body += INDENT * 2 + 'default:\n'
-        body += INDENT * 3 + 'g_warning(\n'
-        body += INDENT * 4 + '"' + PROJECT_NAME + ' was not compiled with support for GTK v%d.%d.%d, program may crash",\n'
-        body += INDENT * 4 + 'gtk_get_major_version(),\n'
-        body += INDENT * 4 + 'gtk_get_minor_version(),\n'
-        body += INDENT * 4 + 'gtk_get_micro_version());\n'
+        body += INDENT * 3 + 'gtk_priv_warn_gtk_version_may_be_unsupported();\n'
         body += INDENT + '}\n'
         body += '\n'
         body += INDENT
@@ -390,7 +403,10 @@ class Struct:
 
     def emit_header(self, generated):
         result = ''
-        result += '/* This file is part of ' + PROJECT_NAME + '\n'
+        result += '/* AUTOGENERATED, DO NOT EDIT DIRECTLY\n'
+        result += ' * See gtk-priv/README.md for more information\n'
+        result += ' *\n'
+        result += ' * This file is part of ' + PROJECT_NAME + '\n'
         result += ' *\n'
         me = path.relpath(__file__, path.dirname(path.dirname(path.dirname(__file__))))
         my_copyright_line = 'Copyright © ' + str(datetime.now().year) + ' ' + me
@@ -403,11 +419,19 @@ class Struct:
         result += '#ifndef ' + self.macro_name() + '\n'
         result += '#define ' + self.macro_name() + '\n'
         result += '\n'
+        result += '#include "common.h"\n'
+        result += '\n'
         result += 'typedef struct ' + self.struct_name + ' ' + self.typedef + ';\n'
         result += '\n'
+        prev_definition = None
         for i, struct in enumerate(self.versions):
             result += '// Version ID ' + str(i) + '\n'
-            result += struct.emit_definition(generated)
+            definition = struct.emit_definition(generated)
+            if prev_definition:
+                result += '// Diff from previous version:\n'
+                result += '\n'.join(diff_between(prev_definition, definition).splitlines()[4:]) + '\n'
+            prev_definition = definition
+            result += definition
             result += '\n'
         result += '// For internal use only\n'
         result += self.emit_get_version_id_fn()
