@@ -336,12 +336,6 @@ custom_shell_surface_get_layer_surface (CustomShellSurface *shell_surface)
         return NULL;
 }
 
-struct zwlr_layer_surface_v1 *
-layer_surface_get_get_zwlr_layer_surface_v1(LayerSurface *self)
-{
-    return self->layer_surface;
-}
-
 void
 layer_surface_set_monitor (LayerSurface *self, GdkMonitor *monitor)
 {
@@ -416,6 +410,8 @@ void
 layer_surface_set_exclusive_zone (LayerSurface *self, int exclusive_zone)
 {
     self->auto_exclusive_zone = FALSE;
+    if (exclusive_zone < -1)
+        exclusive_zone = -1;
     if (self->exclusive_zone != exclusive_zone) {
         self->exclusive_zone = exclusive_zone;
         if (self->layer_surface) {
@@ -437,6 +433,7 @@ layer_surface_auto_exclusive_zone_enable (LayerSurface *self)
 void
 layer_surface_set_keyboard_interactivity (LayerSurface *self, gboolean interactivity)
 {
+    interactivity = (interactivity != FALSE);
     if (self->keyboard_interactivity != interactivity) {
         self->keyboard_interactivity = interactivity;
         if (self->layer_surface) {
