@@ -17,28 +17,52 @@
 #include "gtk-layer-shell.h"
 #include <gtk/gtk.h>
 
-// a LayerSurface * can be safely cast to a CustomShellSurface *
+// A LayerSurface * can be safely cast to a CustomShellSurface *
 typedef struct _LayerSurface LayerSurface;
 
+// Functions that mutate this structure should all be in layer-surface.c to make the logic easier to understand
+// Struct is declared in this header to prevent the need for excess getters
+struct _LayerSurface
+{
+    CustomShellSurface super;
+
+    // Can be set at any time
+    gboolean anchors[GTK_LAYER_SHELL_EDGE_ENTRY_NUMBER]; // The current anchor
+    int margins[GTK_LAYER_SHELL_LAYER_ENTRY_NUMBER]; // The current margins
+    int exclusive_zone; // The current exclusive zone (set either explicitly or automatically)
+    gboolean auto_exclusive_zone; // If to automatically change the exclusive zone to match the window size
+    gboolean keyboard_interactivity; // If this surface should get keyboard input
+    GtkLayerShellLayer layer; // The current layer, needs surface recreation on old layer shell versions
+
+    // Need the surface to be recreated to change
+    GdkMonitor *monitor; // Can be null
+    const char *name_space; // Can be null, freed on destruction
+
+    // Not set by user requests
+    struct zwlr_layer_surface_v1 *layer_surface; // The actual layer surface Wayland object (can be NULL)
+    GtkRequisition current_allocation; // Last size allocation, or (0, 0) if there hasn't been one
+    GtkRequisition cached_layer_size; // Last size sent to zwlr_layer_surface_v1_set_size (starts as 0, 0)
+    GtkRequisition last_configure_size; // Last size received from a configure event
+};
+
 LayerSurface *layer_surface_new (GtkWindow *gtk_window);
 
 // Safe cast, returns NULL if wrong type sent
 LayerSurface *custom_shell_surface_get_layer_surface (CustomShellSurface *shell_surface);
 
-// Getters
-struct zwlr_layer_surface_v1 *layer_surface_get_get_zwlr_layer_surface_v1(LayerSurface *self);
-
 // Surface is remapped in order to set
-void layer_surface_set_layer (LayerSurface *self, enum zwlr_layer_shell_v1_layer layer);
 void layer_surface_set_monitor (LayerSurface *self, GdkMonitor *monitor); // Can be null for default
 void layer_surface_set_name_space (LayerSurface *self, char const* name_space); // Makes a copy of the string, can be null
 
 // Can be set without remapping the surface
+void layer_surface_set_layer (LayerSurface *self, GtkLayerShellLayer layer); // Remaps surface on old layer shell versions
 void layer_surface_set_anchor (LayerSurface *self, GtkLayerShellEdge edge, gboolean anchor_to_edge);
 void layer_surface_set_margin (LayerSurface *self, GtkLayerShellEdge edge, int margin_size);
 void layer_surface_set_exclusive_zone (LayerSurface *self, int exclusive_zone);
 void layer_surface_auto_exclusive_zone_enable (LayerSurface *self);
-
 void layer_surface_set_keyboard_interactivity (LayerSurface *self, gboolean interactivity);
 
+// Returns the effective namespace (default if unset). Does not return ownership. Never returns NULL. Handles null self.
+const char* layer_surface_get_namespace (LayerSurface *self);
+
 #endif // LAYER_SHELL_SURFACE_H
