@@ -9,34 +9,22 @@
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
-#include <stdio.h>
-#include <stdlib.h>
 #include "gtk-layer-shell.h"
+#include "test-common.h"
 
 int main(int argc, char** argv)
 {
-    if (argc != 2)
-    {
-        fprintf(stderr, "Incorrect number of arguments (%d)", argc);
-        exit(1);
-    }
+    ASSERT_EQ(argc, 2, "%d");
 
-    char version_string[1024];
+    char version_provided_by_gtk_layer_shell[1024];
     sprintf(
-        version_string,
+        version_provided_by_gtk_layer_shell,
         "%d.%d.%d",
         gtk_layer_get_major_version(),
         gtk_layer_get_minor_version(),
         gtk_layer_get_micro_version());
 
-    const char* version_arg = argv[1];
-
-    if (strcmp(version_arg, version_string) != 0)
-    {
-        fprintf(stderr, "Version provided by GTK Layer Shell: %s\n", version_string);
-        fprintf(stderr, "Version sent to this test via argument: %s\n", version_arg);
-        exit(1);
-    }
+    ASSERT_STR_EQ(version_provided_by_gtk_layer_shell, argv[1]);
 
     return 0;
 }
